# organelle-segmenter-plugin

The `infer_subc` module is exposed to [Napari](https://napari.org/stable/) via the [organelle-segmenter-plugin](https://github.com/ndcn/organelle-segmenter-plugin) which was co-developed with 'infer_subc'

